@@ -11,40 +11,48 @@ Q_OBJECT
 public:
 	VButton(TQWidget *parent=0, const char *name=0);
 	~VButton();
-	void setKeyCode(unsigned int keycode);
+
 	unsigned int getKeyCode();
-	void setText(const TQString& text);
-	void setShiftText(const TQString& text);
-	void capsPressed(bool press);
-	
-	
+	void setKeyCode(unsigned int keycode);
+	void setText(const TQString &text);
+	void setShiftText(const TQString &text);
+	void setColor(const TQColor &color);
+	void setupTexts(Display *display);
+
 	void reposition(int width, int height);
 	void res();
+
 	static double pw;
 	static double ph;
 
-private:
+protected:
 	bool press;
 	bool inrpt;
-
-protected:
+	bool inside;
+	bool isAlpha;
 	unsigned int keycode;
-	TQString u;
-	TQString l;
+	TQString normalText;
+	TQString capsText;
+	TQString shiftText;
+	TQString altGrText;
+	TQString capsShiftText;
+	TQString altGrShiftText;
 	TQRect orig_size;
-    void timerEvent ( TQTimerEvent * );
+
+	void timerEvent ( TQTimerEvent * );
 
 public slots:
 	void sendKey();
-	void shiftPressed(bool press);
+	void shiftCapsAltGrPressed(bool shift, bool caps, bool altGrState);
 
 protected slots:
+	void enterEvent(TQEvent *e);
+	void leaveEvent(TQEvent *e);
 	void mousePressEvent(TQMouseEvent *e);
 	void mouseReleaseEvent(TQMouseEvent *e);
 
 signals:
 	void keyClick(unsigned int keycode);
-
 };
 
 #endif
